@@ -183,6 +183,10 @@ static mrss_t *rss_open(const feed_t *feed)
     str_t url = feed_get_provided_url(feed);
     feed_url_type_t urltype = feed_get_url_type(feed);
 
+    mrss_options_t options = {
+        .user_agent = PACKAGE_NAME "/" PACKAGE_VERSION
+    };
+
     say("feed [%s]", feed_get_name(feed));
     whisper(" opening address [%.*s] (%s)",
             STR_FMT(&url),
@@ -198,7 +202,7 @@ static mrss_t *rss_open(const feed_t *feed)
         error = mrss_parse_url_with_options_and_error(
             nul_term_url,
             &rss,
-            NULL,
+            &options,
             &code
         );
         break;
