@@ -33,6 +33,7 @@
 
 #include "outfmt_parser.h"
 #include "outfmt.h"
+#include "text.h"
 
 enum {
     /* TODO: these assignments are arbitrary, and they
@@ -481,6 +482,31 @@ static int print_eval(ofmt_t ofmt, const ofmt_evaluate_params_t *params)
     return 0;
 }
 
+static int dry_run(const launcher_run_t *lch)
+{
+    char buffer[60];
+
+    warnx("dry_run!");
+    warnx(" would execute: %s", text_join_argv(
+        buffer,
+        sizeof(buffer),
+        lch->argv
+    ));
+
+    if (lch->chdir_to)
+        warnx(" chdir: %s", lch->chdir_to);
+
+    if (lch->input.bytes)
+        warnx(" pipe in: %s", text_short(
+            buffer,
+            sizeof(buffer),
+            lch->input.bytes,
+            &lch->input.len
+        ));
+
+    return 0;   /* of course */
+}
+
 static int launch(ofmt_t ofmt, const launcher_run_t *lch)
 {
     int status;
@@ -501,7 +527,6 @@ static int subproc_eval(ofmt_t ofmt, const ofmt_evaluate_params_t *params)
 {
     struct subproc *subproc = &ofmt->subproc;
     char const **argv = subproc->argv;
-    const char *value;
 
     char evaluation_buffer[max_eval_buflen];
     int w = 0;
@@ -510,6 +535,7 @@ static int subproc_eval(ofmt_t ofmt, const ofmt_evaluate_params_t *params)
     for (int i = 0; i < subproc->segwrite; ++i) {
         struct subproc_segment *s;
         size_t value_len;
+        const char *value = NULL;
 
         s = &subproc->segments[i];
 
@@ -547,20 +573,24 @@ static int subproc_eval(ofmt_t ofmt, const ofmt_evaluate_params_t *params)
             evaluation_buffer[w++] = '\0';
     }
 
-    value = NULL;
+    const char *input_stdin = NULL;
     if (subproc->pipe_enabled) {
         if (!ofmt->pipe_resolver)
             errx(EX_SOFTWARE, "software bug: unregistered pipe resolver! Skipping");
 
-        value = ofmt->pipe_resolver(params->item, ofmt->opaque);
+        input_stdin = ofmt->pipe_resolver(params->item, ofmt->opaque);
     }
 
-    return launch(ofmt, &(launcher_run_t){
+    const launcher_run_t run = {
         .argv = argv,
         .chdir_to = params->opt_subproc_chdir,
-        .input.bytes = (void *)value,
-        .input.len = value ? strlen(value) : 0,
-    });
+        .input.bytes = (void *)input_stdin,
+        .input.len = input_stdin ? strlen(input_stdin) : 0,
+    };
+
+    return params->dry_run
+        ? dry_run(&run)
+        : launch(ofmt, &run);
 }
 
 ofmt_t ofmt_new(void)
